{
	"name" : "Productivity Analysis",
	"version" : "1.0",
	"depends" : ["base"],
	"author" : "Tiny",
	"website" : "",
	"category" : "Generic Modules/Human Resources",
	"description": "A module that analyse the productivity of Tiny ERP users in terms of creation and modification of objects. It is able to render graphs, compare users, eso.",
	"init_xml" : [ ],
	"demo_xml" : [ ],
	"update_xml" : [
		"productivity_analysis_view.xml",
		"productivity_analysis_wizard.xml",
		"productivity_analysis_report.xml",
	],
	"active": False,
	"installable": True
}
